SpecId

Enum SpecId 

#[repr(u8)]
pub enum SpecId {
Show 15 variants FRONTIER = 0, HOMESTEAD = 1, TANGERINE = 2, SPURIOUS_DRAGON = 3, BYZANTIUM = 4, PETERSBURG = 5, ISTANBUL = 6, BERLIN = 7, LONDON = 8, MERGE = 9, SHANGHAI = 10, CANCUN = 11, PRAGUE = 12, OSAKA = 13, AMSTERDAM = 14,
}
Specification IDs and their activation points.

Information was obtained from the Ethereum Execution Specifications.

Variants



FRONTIER = 0

Frontier

Activated at block 1



HOMESTEAD = 1

Homestead

Activated at block 1150000



TANGERINE = 2

Tangerine Whistle

Activated at block 2463000



SPURIOUS_DRAGON = 3

Spurious Dragon

Activated at block 2675000



BYZANTIUM = 4

Byzantium

Activated at block 4370000



PETERSBURG = 5

Petersburg

Activated at block 7280000



ISTANBUL = 6

Istanbul

Activated at block 9069000



BERLIN = 7

Berlin

Activated at block 12244000



LONDON = 8

London

Activated at block 12965000



MERGE = 9

Paris/Merge

Activated at block 15537394



SHANGHAI = 10

Shanghai

Activated at block 17034870 (timestamp 1681338455)



CANCUN = 11

Cancun

Activated at block 19426587 (timestamp 1710338135)



PRAGUE = 12

Prague

Activated at block 22431084



OSAKA = 13

Osaka

Activated at block 23935694



AMSTERDAM = 14

Amsterdam

Activated at block TBD

Implementations

Source

impl SpecId

pub const NEXT: Self = Self::AMSTERDAM

The latest known spec. This may refer to a highly experimental hard fork that is not yet finalized or deployed on any network.

Warning: This value will change between minor versions as new hard forks are added. Do not rely on it for stable behavior.

pub const fn try_from_u8(spec_id: u8) -> Option<Self>

Returns the SpecId for the given u8.

pub const fn is_enabled_in(self, other: Self) -> bool

Returns true if the given specification ID is enabled in this spec.